<?php
/**
 * Plugins for TGM usage.
 * @package   DGWork
 */

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}
require_once DGWORK_INC_DIR. 'admin/class-tgm-plugin-activation.php';

/**
 * Gets all recommended and required plugins for use in TGM plugin.
 *
 * @since 5.1.6
 */
function dgwork_get_required_and_recommened_plugins() {


	$is_plugins_page = false;
	if ( ( isset( $_GET['page'] ) && 'dgwork-plugins' === $_GET['page'] ) ||
		 ( isset( $_GET['page'] ) && 'install-required-plugins' === $_GET['page'] ) ||
		 ( isset( $_SERVER['HTTP_REFERER'] ) && false !== strpos( esc_url_raw( wp_unslash( $_SERVER['HTTP_REFERER'] ) ), 'HTTP_REFERER' ) )
	) {
		$is_plugins_page = true;
	}

	// Get the bundled plugin information.
	$bundled_plugins = DGWork()->get_bundled_plugins();

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$key_url_md5 = 'Wswb86sr07^d1a7y#';
	$plugins = array(
		'easy-digital-downloads' => array(
			'name'      => esc_html__('Easy Digital Downloads','dgwork'),
			'slug'      => 'easy-digital-downloads',
			'required'  => true,
			'image_url' => DGWORK_INC_URI.'admin/img/plugins/edd.jpg',
		),
		$bundled_plugins['themevan-shortcodes']['slug'] => array(
			'name'               => $bundled_plugins['themevan-shortcodes']['name'],
			'slug'               => $bundled_plugins['themevan-shortcodes']['slug'],
			'source'             => 'https://www.themevan.com/download.php?'.tmv_encrypt_url('purchase_key='.get_option('purchase_key').'&item_id='.DGWORK_ITEM_ID.'&file='.$bundled_plugins['themevan-shortcodes']['slug'], $key_url_md5),
			'required'           => true,
			'version'            => $bundled_plugins['themevan-shortcodes']['version'],
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
			'image_url'          => DGWORK_INC_URI.'admin/img/plugins/themevan_shortcodes.png',
		),
		$bundled_plugins['visual_composer']['slug'] => array(
			'name'               => $bundled_plugins['visual_composer']['name'],
			'slug'               => $bundled_plugins['visual_composer']['slug'],
			'source'             => 'https://www.themevan.com/download.php?'.tmv_encrypt_url('purchase_key='.get_option('purchase_key').'&item_id='.DGWORK_ITEM_ID.'&file='.$bundled_plugins['visual_composer']['slug'], $key_url_md5),
			'required'           => true,
			'version'            => $bundled_plugins['visual_composer']['version'],
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
			'image_url'          => DGWORK_INC_URI.'admin/img/plugins/visual_composer.png',
		),
		$bundled_plugins['slider_revolution']['slug'] => array(
			'name'               => $bundled_plugins['slider_revolution']['name'],
			'slug'               => $bundled_plugins['slider_revolution']['slug'],
			'source'             => 'https://www.themevan.com/download.php?'.tmv_encrypt_url('purchase_key='.get_option('purchase_key').'&item_id='.DGWORK_ITEM_ID.'&file='.$bundled_plugins['slider_revolution']['slug'],$key_url_md5),
			'required'           => true,
			'version'            => $bundled_plugins['slider_revolution']['version'],
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => '',
			'image_url'          => DGWORK_INC_URI.'admin/img/plugins/rev_slider.png',
		),
	    'contact-form-7' => array(
			'name'      => 'Contact Form 7',
			'slug'      => 'contact-form-7',
			'required'  => true,
			'image_url' => DGWORK_INC_URI.'admin/img/plugins/cf7.png',
		),
		'instagram-feed' => array(
			'name'      => 'Instagram Feed',
			'slug'      => 'instagram-feed',
			'required'  => false,
			'image_url' => DGWORK_INC_URI.'admin/img/plugins/instagram-feed.jpg',
		),
		'mailchimp-for-wp' => array(
			'name'      => 'MailChimp for WordPress',
			'slug'      => 'mailchimp-for-wp',
			'required'  => false,
			'image_url' => DGWORK_INC_URI.'admin/img/plugins/mailchimp_for_wordpress.png',
		)
		
	);

	return $plugins;
}

/**
 * Require the installation of any required and/or recommended third-party plugins here.
 * See http://tgmpluginactivation.com/ for more details
 */
function dgwork_register_required_and_recommended_plugins() {

	// Get all required and recommended plugins.
	$plugins = dgwork_get_required_and_recommened_plugins();

	// Change this to your theme text domain, used for internationalising strings.
	$theme_text_domain = 'dgwork';

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'        	=> $theme_text_domain,
		'default_path'  	=> '',
		'parent_slug' 		=> 'themes.php',
		'menu'            	=> 'plugins',
		'has_notices'     	=> false,
		'is_automatic'    	=> true,
		'dismissable'		=> true,
		'message'         	=> '',
	);

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'dgwork_register_required_and_recommended_plugins' );

/**
 * Returns the user capability for showing the notices.
 *
 * @return string
 */
function dgwork_tgm_show_admin_notice_capability() {
	return 'edit_theme_options';
}
add_filter( 'tgmpa_show_admin_notice_capability', 'dgwork_tgm_show_admin_notice_capability' );

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
