<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 * * @package DGWork
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
if ( ! function_exists( 'dgwork_body_classes' ) ) :
function dgwork_body_classes( $classes ) {
  global $post,$dgwork_option;

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

  if($dgwork_option['header_layout']=='3'){
    $classes[] = 'centered-logo';
  }

  if(is_single() && get_post_type( $post->ID ) == 'post' && get_post_meta($post->ID, "_dgwork_post_template", true)=='0' || is_page_template('page-templates/page-sidebar.php')){
    $classes[]='sidebar-layout';
  }

  if(is_single() && get_post_type( $post->ID ) == 'download' && get_post_meta($post->ID, "_dgwork_product_template", true)=='1'){
    $classes[]='custom-edd-product-template no-main-background';
  }

  if(is_single() && get_post_type( $post->ID ) == 'download' && get_post_meta($post->ID, "_dgwork_product_template", true)=='2'){
    $classes[]='custom-edd-product-template custom-edd-product-template-sidebar no-main-background';
  }

  if(is_single() && get_post_type( $post->ID ) == 'download'){
    $header_text_aligned=get_post_meta($post->ID, "_dgwork_page_header_text_aligned", true);
    switch($header_text_aligned){
      case "left":
        $classes[]='';
      break;

      case "right":
        $classes[]='custom-edd-product-header-alignright';
      break;

      case "center":
        $classes[]='custom-edd-product-header-aligncenter';
      break;
    }
  }

  if(is_page_template('page-templates/page-left-sidebar.php')){
    $classes[]='sidebar-layout left-sidebar-layout';
  }

  if(is_home() || is_tag()){
     $classes[]='sidebar-layout';
  }

  if(is_page_template('page-templates/page-downloads.php')){
     $classes[]='no-main-background';
  }
  
  if(is_category()){
    $cat_id = get_query_var('cat');
    $cat_data = get_option("taxonomy_$cat_id");
    $cat_template=$cat_data['template'];

    switch($cat_template){
      case "standard":
        $classes[]='sidebar-layout';
      break;

      case "masonry":
        $classes[]='no-main-background';
      break;

      case "overlap":
        $classes[]='no-main-background';
      break;

      case "grid":
        $classes[]='no-main-background';
      break;
    }
  }
	
	if ( class_exists( 'Easy_Digital_Downloads') ){
	     $classes[]='edd';
	}

  if(is_page() || is_single() && get_post_type( $post->ID ) == 'download'){
    $page_transparent_nav = esc_attr(get_post_meta( $post->ID, '_dgwork_transparent_nav', true ));
    if($page_transparent_nav=='on'){
          $classes[]='page_transparent_nav';
    }
  }

  if(is_page_template('page-templates/page-blank-header.php')){
        $classes[]='page-transparent-content-bg';
  }

	return $classes;
}
endif;
add_filter( 'body_class', 'dgwork_body_classes' );

/**
 * Remove query strings from static resources
 */
if ( ! function_exists( 'dgwork_remove_script_version' ) ) :
function dgwork_remove_script_version( $src ){
  $parsed = parse_url($src);

  if (isset($parsed['query'])) {
    parse_str($parsed['query'], $qrystr);
    if (isset($qrystr['ver'])) {
      unset($qrystr['ver']); 
    }
    $parsed['query'] = http_build_query($qrystr);
  }

  $src = '';
  $src .= (!empty($parsed['scheme'])) ? $parsed['scheme'].'://' : '';
  $src .= (!empty($parsed['host'])) ? $parsed['host'] : '';
  $src .= (!empty($parsed['path'])) ? $parsed['path'] : '';
  $src .= (!empty($parsed['query'])) ? '?'.$parsed['query'] : '';

  return $src;
}
endif;
//add_filter( 'script_loader_src', 'dgwork_remove_script_version', 15, 1 );
//add_filter( 'style_loader_src', 'dgwork_remove_script_version', 15, 1 );

/**
 * Modify the default WordPress search form
 */
if ( ! function_exists( 'dgwork_default_search_form' ) ) :
function dgwork_default_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform_default" class="searchform" action="' . esc_url(home_url( '/' )) . '" >
    <div><label class="screen-reader-text" for="s">' . esc_html__( 'Search for:','dgwork' ) . '</label>
    <input type="text" value="' . esc_html(get_search_query()) . '" name="s" id="s" />
    <input type="submit" id="searchsubmit" value="'. esc_attr__( 'Search','dgwork' ) .'" />
    <input type="hidden" name="post_type" id="post_type_default" value="post" />
    </div>
    </form>';

    return $form;
}
endif;
add_filter( 'get_search_form', 'dgwork_default_search_form', 100 );


/*Custom Post Navigation*/
if ( ! function_exists( 'dgwork_post_navigation' ) ) :
function dgwork_post_navigation( $args = array() ) {
    $args = wp_parse_args( $args, array(
        'prev_text'          => '%title',
        'next_text'          => '%title',
        'screen_reader_text' => __( 'Post navigation','dgwork' ),
    ) );

    $navigation = '';
    $previous   = get_previous_post_link( '<div class="nav-previous">%link</div>', $args['prev_text'] );
    $next       = get_next_post_link( '<div class="nav-next">%link</div>', $args['next_text'] );
    $class      = 'post-navigation';
    
    // Only add markup if there's somewhere to navigate to.
    if ( $previous || $next ) {
        $navigation = _navigation_markup( $previous . $next, $class, $args['screen_reader_text'] );
    }

    echo wp_kses_post($navigation);
}
endif;

/*Custom archive title function*/
add_filter( 'get_the_archive_title', function ($title) {

    if ( is_category() ) {
            $title = single_cat_title( '', false );
        } elseif ( is_tag() ) {
            $title = single_tag_title( '', false );
        } elseif ( is_author() ) {
            $title = '<span class="vcard">' . esc_html(get_the_author()) . '</span>' ;

        }

    return $title;

});

/*Insert header codes*/
add_action('wp_head', 'dgwork_header_codes');
if ( ! function_exists( 'dgwork_header_codes' ) ) :
function dgwork_header_codes(){
   global $dgwork_option;
   echo stripslashes($dgwork_option['header_code']);
   
   if(isset($dgwork_option['custom_css']) && $dgwork_option['custom_css']){
    wp_enqueue_style( 'dgwork-custom-css', get_template_directory_uri() .'/assets/css/custom.css', '', null );
     wp_add_inline_style( 'dgwork-custom-css', stripslashes($dgwork_option['custom_css']) );
   }
}
endif;

/*Insert footer codes*/
add_action('wp_footer', 'dgwork_footer_codes');
if ( ! function_exists( 'dgwork_footer_codes' ) ) :
function dgwork_footer_codes(){
   global $dgwork_option;
   if(isset($dgwork_option['custom_javascript']) && $dgwork_option['custom_javascript']){
      wp_add_inline_script('dgwork-script',stripslashes($dgwork_option['custom_javascript']));
   }
   echo stripslashes($dgwork_option['footer_code']);
}
endif;

/* Script Text */
add_action('wp_footer', 'dgwork_script_text');
if ( ! function_exists( 'dgwork_script_text' ) ) :
function dgwork_script_text(){
  wp_add_inline_script('dgwork-script',
    'var register_text="'.esc_html__('Register','dgwork').'";
     var psw_error="'.esc_html__('Error: The passwords you entered do not match. Please try again.','dgwork').'";
     var save_text="'.esc_html__('Saving...','dgwork').'";
     var save_text="'.esc_html__('Save Changes','dgwork').'";
    ');
}
endif;